@@ -2,6 +2,7 @@
 #' 
 #' Creates a Docker file to be used with the GitHub Actions (GHA) workflows
 #' distributed by \pkg{rworkflows}.
+#' @param base_image Base Docker image to use.
 #' @param save_dir Directory to save the Docker file to.
 #' @param path Path to the Docker file.
 #' @param force_new If a Docker file already exists, overwrite it 
@@ -17,9 +18,11 @@
 #' path <- use_dockerfile(save_dir=tempdir())
 use_dockerfile <- function(save_dir=here::here(),
                            path=file.path(save_dir,"Dockerfile"),
+                           base_image=construct_cont()[[1]],
                            force_new=FALSE,
                            show=FALSE,
                            verbose=TRUE){
+  # devoptera::args2vars(use_dockerfile)
   
   if(file.exists(path) &&
      isFALSE(force_new)){
@@ -31,6 +34,9 @@ use_dockerfile <- function(save_dir=here::here(),
                                  package = "rworkflows"), 
               to = path,  
               overwrite = TRUE)
+    txt <- readLines(path)
+    txt <- gsub("^FROM \\{BASE_IMAGE\\}",paste("FROM",base_image),txt)
+    writeLines(txt,path)
   }
   if(isTRUE(show)){
     messager("Docker file preview:",v=verbose)
