@@ -1,3 +1,4 @@
+skip_if_offline()
 test_that("get_description works", {
   
   run_tests <- function(dl){
@@ -94,10 +95,7 @@ test_that("get_description works", {
   }  
   #### Search GitHub repos ####
   d14 <- get_description(refs="neurogenomics/orthogene",
+                         paths=NULL,
                          use_wd = FALSE) 
-  if(is_gha()){
-    testthat::expect_false(methods::is(d14[[1]],"description"))
-  } else {
-    testthat::expect_true(methods::is(d14[[1]],"description"))
-  }
+  testthat::expect_true(methods::is(d14[[1]],"description"))
 })
